@@ -9,7 +9,7 @@ use PerlX::Assert ();
 package PerlX::Assert::DD;
 
 our $AUTHORITY = 'cpan:TOBYINK';
-our $VERSION   = '0.904';
+our $VERSION   = '0.905';
 our @ISA       = qw( PerlX::Assert );
 
 # Would be nice to replace this with an XS version
@@ -99,7 +99,7 @@ sub _install_assert
 				$self->inc_offset(1);
 				$self->skipspace;
 				
-				if ($self->get_remainder =~ /\A{/)
+				if ($self->get_remainder =~ /\A\{/)
 				{
 					require Carp;
 					Carp::croak("Unexpected comma between assertion name and block");
